@@ -37,7 +37,6 @@ import com.google.gson.JsonElement;
 import com.google.gson.JsonPrimitive;
 import com.google.gson.JsonSerializationContext;
 import com.google.gson.JsonSerializer;
-import com.google.gson.common.MoreAsserts;
 import com.google.gson.common.TestTypes.BagOfPrimitives;
 import com.google.gson.reflect.TypeToken;
 
@@ -92,7 +91,7 @@ public class CollectionTest extends TestCase {
   }
 
   public void testLinkedListSerialization() {
-    List<String> list = new LinkedList<String>();
+    List<String> list = new LinkedList<>();
     list.add("a1");
     list.add("a2");
     Type linkedListType = new TypeToken<LinkedList<String>>() {}.getType();
@@ -110,7 +109,7 @@ public class CollectionTest extends TestCase {
   }
 
   public void testQueueSerialization() {
-    Queue<String> queue = new LinkedList<String>();
+    Queue<String> queue = new LinkedList<>();
     queue.add("a1");
     queue.add("a2");
     Type queueType = new TypeToken<Queue<String>>() {}.getType();
@@ -162,7 +161,7 @@ public class CollectionTest extends TestCase {
   }
 
   public void testNullsInListSerialization() {
-    List<String> list = new ArrayList<String>();
+    List<String> list = new ArrayList<>();
     list.add("foo");
     list.add(null);
     list.add("bar");
@@ -173,7 +172,7 @@ public class CollectionTest extends TestCase {
   }
 
   public void testNullsInListDeserialization() {
-    List<String> expected = new ArrayList<String>();
+    List<String> expected = new ArrayList<>();
     expected.add("foo");
     expected.add(null);
     expected.add("bar");
@@ -186,7 +185,7 @@ public class CollectionTest extends TestCase {
   }
 
   public void testCollectionOfObjectSerialization() {
-    List<Object> target = new ArrayList<Object>();
+    List<Object> target = new ArrayList<>();
     target.add("Hello");
     target.add("World");
     assertEquals("[\"Hello\",\"World\"]", gson.toJson(target));
@@ -196,7 +195,7 @@ public class CollectionTest extends TestCase {
   }
 
   public void testCollectionOfObjectWithNullSerialization() {
-    List<Object> target = new ArrayList<Object>();
+    List<Object> target = new ArrayList<>();
     target.add("Hello");
     target.add(null);
     target.add("World");
@@ -207,14 +206,14 @@ public class CollectionTest extends TestCase {
   }
 
   public void testCollectionOfStringsSerialization() {
-    List<String> target = new ArrayList<String>();
+    List<String> target = new ArrayList<>();
     target.add("Hello");
     target.add("World");
     assertEquals("[\"Hello\",\"World\"]", gson.toJson(target));
   }
 
   public void testCollectionOfBagOfPrimitivesSerialization() {
-    List<BagOfPrimitives> target = new ArrayList<BagOfPrimitives>();
+    List<BagOfPrimitives> target = new ArrayList<>();
     BagOfPrimitives objA = new BagOfPrimitives(3L, 1, true, "blah");
     BagOfPrimitives objB = new BagOfPrimitives(2L, 6, false, "blahB");
     target.add(objA);
@@ -298,7 +297,7 @@ public class CollectionTest extends TestCase {
   }
 
   public void testWildcardCollectionField() throws Exception {
-    Collection<BagOfPrimitives> collection = new ArrayList<BagOfPrimitives>();
+    Collection<BagOfPrimitives> collection = new ArrayList<>();
     BagOfPrimitives objA = new BagOfPrimitives(3L, 1, true, "blah");
     BagOfPrimitives objB = new BagOfPrimitives(2L, 6, false, "blahB");
     collection.add(objA);
@@ -329,7 +328,7 @@ public class CollectionTest extends TestCase {
   public void testUserCollectionTypeAdapter() {
     Type listOfString = new TypeToken<List<String>>() {}.getType();
     Object stringListSerializer = new JsonSerializer<List<String>>() {
-      public JsonElement serialize(List<String> src, Type typeOfSrc,
+      @Override public JsonElement serialize(List<String> src, Type typeOfSrc,
           JsonSerializationContext context) {
         return new JsonPrimitive(src.get(0) + ";" + src.get(1));
       }
@@ -341,7 +340,7 @@ public class CollectionTest extends TestCase {
   }
 
   static class HasArrayListField {
-    ArrayList<Long> longs = new ArrayList<Long>();
+    ArrayList<Long> longs = new ArrayList<>();
   }
 
   @SuppressWarnings("rawtypes")
@@ -378,7 +377,7 @@ public class CollectionTest extends TestCase {
     }
   }
   public void testSetSerialization() {
-    Set<Entry> set = new HashSet<Entry>();
+    Set<Entry> set = new HashSet<>();
     set.add(new Entry(1));
     set.add(new Entry(2));
     String json = gson.toJson(set);
