@@ -35,7 +35,7 @@ import com.google.gson.common.MoreAsserts;
 public final class LinkedTreeMapTest extends TestCase {
 
   public void testIterationOrder() {
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     map.put("a", "android");
     map.put("c", "cola");
     map.put("b", "bbq");
@@ -44,7 +44,7 @@ public final class LinkedTreeMapTest extends TestCase {
   }
 
   public void testRemoveRootDoesNotDoubleUnlink() {
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     map.put("a", "android");
     map.put("c", "cola");
     map.put("b", "bbq");
@@ -57,7 +57,7 @@ public final class LinkedTreeMapTest extends TestCase {
   }
 
   public void testPutNullKeyFails() {
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     try {
       map.put(null, "android");
       fail();
@@ -66,7 +66,7 @@ public final class LinkedTreeMapTest extends TestCase {
   }
 
   public void testPutNonComparableKeyFails() {
-    LinkedTreeMap<Object, String> map = new LinkedTreeMap<Object, String>();
+    LinkedTreeMap<Object, String> map = new LinkedTreeMap<>();
     try {
       map.put(new Object(), "android");
       fail();
@@ -74,19 +74,19 @@ public final class LinkedTreeMapTest extends TestCase {
   }
 
   public void testContainsNonComparableKeyReturnsFalse() {
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     map.put("a", "android");
     assertFalse(map.containsKey(new Object()));
   }
 
   public void testContainsNullKeyIsAlwaysFalse() {
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     map.put("a", "android");
     assertFalse(map.containsKey(null));
   }
 
   public void testPutOverrides() throws Exception {
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     assertNull(map.put("d", "donut"));
     assertNull(map.put("e", "eclair"));
     assertNull(map.put("f", "froyo"));
@@ -98,7 +98,7 @@ public final class LinkedTreeMapTest extends TestCase {
   }
 
   public void testEmptyStringValues() {
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     map.put("a", "");
     assertTrue(map.containsKey("a"));
     assertEquals("", map.get("a"));
@@ -106,7 +106,7 @@ public final class LinkedTreeMapTest extends TestCase {
 
   public void testLargeSetOfRandomKeys() throws Exception {
     Random random = new Random(1367593214724L);
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     String[] keys = new String[1000];
     for (int i = 0; i < keys.length; i++) {
       keys[i] = Integer.toString(Math.abs(random.nextInt()), 36) + "-" + i;
@@ -121,7 +121,7 @@ public final class LinkedTreeMapTest extends TestCase {
   }
 
   public void testClear() {
-    LinkedTreeMap<String, String> map = new LinkedTreeMap<String, String>();
+    LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
     map.put("a", "android");
     map.put("c", "cola");
     map.put("b", "bbq");
@@ -131,13 +131,13 @@ public final class LinkedTreeMapTest extends TestCase {
   }
 
   public void testEqualsAndHashCode() throws Exception {
-    LinkedTreeMap<String, Integer> map1 = new LinkedTreeMap<String, Integer>();
+    LinkedTreeMap<String, Integer> map1 = new LinkedTreeMap<>();
     map1.put("A", 1);
     map1.put("B", 2);
     map1.put("C", 3);
     map1.put("D", 4);
 
-    LinkedTreeMap<String, Integer> map2 = new LinkedTreeMap<String, Integer>();
+    LinkedTreeMap<String, Integer> map2 = new LinkedTreeMap<>();
     map2.put("C", 3);
     map2.put("B", 2);
     map2.put("D", 4);
@@ -149,7 +149,7 @@ public final class LinkedTreeMapTest extends TestCase {
   public void testJavaSerialization() throws IOException, ClassNotFoundException {
     ByteArrayOutputStream out = new ByteArrayOutputStream();
     ObjectOutputStream objOut = new ObjectOutputStream(out);
-    Map<String, Integer> map = new LinkedTreeMap<String, Integer>();
+    Map<String, Integer> map = new LinkedTreeMap<>();
     map.put("a", 1);
     objOut.writeObject(map);
     objOut.close();
@@ -162,7 +162,7 @@ public final class LinkedTreeMapTest extends TestCase {
 
   @SafeVarargs
   private final <T> void assertIterationOrder(Iterable<T> actual, T... expected) {
-    ArrayList<T> actualList = new ArrayList<T>();
+    ArrayList<T> actualList = new ArrayList<>();
     for (T t : actual) {
       actualList.add(t);
     }
